@@ -8,15 +8,10 @@ from ipykernel.ipkernel import IPythonKernel
 
 
 class Kernel(IPythonKernel):
+    # help_links = List([]).tag(config=True)
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        from . import load_ipython_extension
-
-        load_ipython_extension(self.shell)
-        with suppress(BaseException):
-            from .widgets import load_ipython_extension
-
-            load_ipython_extension(self.shell)
+        self.shell.magics_manager.magics["line"]["reload_ext"]("pidgy")
 
 
 if __name__ == "__main__":
