@@ -2,6 +2,7 @@
 
 the command line application installs the kernel"""
 
+from contextlib import suppress
 from sys import argv
 
 from ipykernel.ipkernel import IPythonKernel
@@ -10,6 +11,5 @@ from ipykernel.ipkernel import IPythonKernel
 class Kernel(IPythonKernel):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        from .. import load_ipython_extension
 
-        load_ipython_extension(self.shell)
+        self.shell.magics_manager.magics["line"]["reload_ext"]("pidgy")
